@@ -36,7 +36,7 @@
  * @author Nicolas Ternisien
  */
 class ApacheAccessReader : public DefaultReader {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
