@@ -44,7 +44,7 @@
  * @author Nicolas Ternisien
  */
 class DefaultReader : public Reader {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
