@@ -29,7 +29,7 @@
 #include "loggerDialogBase.h"
 
 class LoggerDialog: public LoggerDialogBase {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		LoggerDialog(TQWidget *parent = 0, const char *name = 0);
