@@ -31,7 +31,7 @@
 
 class SpecificFileList : public FileList {
 
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
